using System;
using System.Data;
using System.Data.OleDb;

class DbSample
{
	static string SampleDbPath =
		@"e:\Documents\Teaching\.Net\Mine\Samples\ADO\books.mdb";
	
	static OleDbConnection myConnection;

	static void ReaderDemo()
	{
		OleDbCommand myCommand;
		myCommand = new OleDbCommand("SELECT * FROM Books", myConnection);

		OleDbDataReader myReader = myCommand.ExecuteReader();

		Console.WriteLine("All books in database:");
		while(myReader.Read())
		{
			object myObject = myReader["BookName"];
			Console.WriteLine(myObject.ToString());
		}
		myReader.Close();

		myCommand = new OleDbCommand("SELECT COUNT(*) FROM Books", myConnection);
		Console.WriteLine("\nBooks count - {0}", myCommand.ExecuteScalar());
	}

	static void ParameterDemo()
	{
        OleDbCommand myCommand = 
			new OleDbCommand("SELECT COUNT(*) FROM Books WHERE (AuthorID = ?)", 
						     myConnection);
		myCommand.Parameters.Add("AuthorID", OleDbType.VarChar);
		myCommand.Parameters[0].Value = 0;

		Console.WriteLine("\nBooks count by author - {0}", myCommand.ExecuteScalar());
	}

	static void AdapterDemo()
	{
		OleDbDataAdapter myAdapter = new 
			OleDbDataAdapter("SELECT * FROM Books", myConnection);

		DataSet myDataSet = new DataSet();

		myAdapter.Fill(myDataSet);

		for(int i = 0; i < myDataSet.Tables[0].Rows.Count; ++i)
		{
			Console.WriteLine(myDataSet.Tables[0].Rows[i].ItemArray[2].ToString());
		}
	}

	static void TransactionDemo()
	{
		OleDbTransaction myTransaction = myConnection.BeginTransaction();
		OleDbCommand dropBooks = new OleDbCommand("DROP TABLE Books", myConnection);
		//OleDbCommand dropAuthors = new OleDbCommand("DROP TABLE AuthorsNonEx", myConnection);
		//OleDbCommand dropAuthors = new OleDbCommand("DROP TABLE Authors", myConnection);
		
		dropBooks.Transaction = myTransaction;
		dropAuthors.Transaction = myTransaction;

		try
		{
			dropBooks.ExecuteNonQuery();
			dropAuthors.ExecuteNonQuery();
			myTransaction.Commit();
		}
		catch(Exception e)
		{
			Console.WriteLine(e.Message);
			myTransaction.Rollback();
		}
	}

	static void Main(string[] args)
	{
		myConnection = new OleDbConnection();
		myConnection.ConnectionString = 
			"Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" +
			SampleDbPath;

		myConnection.Open();
		
		ReaderDemo();
		ParameterDemo();
		AdapterDemo();
		TransactionDemo();

		myConnection.Close();
	}
}
